#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Button.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Group.H>
#include <FL/Fl_Round_Button.H>
#include <FL/Fl_Light_Button.H>

static Fl_Double_Window *main_win=(Fl_Double_Window *)0;
static Fl_Double_Window *sub_win=(Fl_Double_Window *)0;
static Fl_Button *bt_1=(Fl_Button *)0;
static Fl_Button *quit_bt=(Fl_Button *)0;
static Fl_Button *hide_bt=(Fl_Button *)0;
static Fl_Box *sub_label=(Fl_Box *)0;
static Fl_Round_Button *rb_1=(Fl_Round_Button *)0;
static Fl_Round_Button *rb_2=(Fl_Round_Button *)0;
static Fl_Round_Button *rb_3=(Fl_Round_Button *)0;

static void set_modality(Fl_Round_Button*, void *v) {
  fl_intptr_t d = (fl_intptr_t)v;
  main_win->show();
  sub_win->hide();
  sub_win->clear_modal_states();
  if (d == 1) {
    sub_win->set_modal();
    sub_label->label("Modal Window");
  }
  else if (d == 2) {
    sub_win->set_non_modal();
    sub_label->label("Non-modal Window");
  }
  else {
    sub_label->label("Normal Window");
  }
  sub_win->show();
}

static void cb_show_child(Fl_Button*, void*) {
  sub_win->show();
}

static void cb_hide_child(Fl_Button*, void*) {
  sub_win->hide();
}

static void cb_quit_bt(Fl_Button*, void*) {
  sub_win->hide();
  main_win->hide();
}

int main(int argc, char **argv) {
  { sub_win = new Fl_Double_Window(464, 320, "Child Window");
  { hide_bt = new Fl_Button(390, 280, 64, 30, "Hide");
  hide_bt->callback((Fl_Callback*)cb_hide_child);
    } // Fl_Button* hide_bt
    { sub_label = new Fl_Box(114, 62, 252, 53, "Normal Window");
    sub_label->box(FL_FLAT_BOX);
    sub_label->labelsize(20);
    } // Fl_Box* sub_label
    { Fl_Group* o = new Fl_Group(25, 210, 141, 100);
      o->box(FL_DOWN_BOX);
      { rb_1 = new Fl_Round_Button(33, 225, 130, 24, "Normal");
      rb_1->type(102);
      rb_1->down_box(FL_ROUND_DOWN_BOX);
      rb_1->value(1);
      rb_1->callback((Fl_Callback*)set_modality, 0);
      } // Fl_Round_Button* rb_1
      { rb_2 = new Fl_Round_Button(33, 251, 130, 24, "Modal");
      rb_2->type(102);
      rb_2->down_box(FL_ROUND_DOWN_BOX);
      rb_2->callback((Fl_Callback*)set_modality, (void*)1);
      } // Fl_Round_Button* rb_2
      { rb_3 = new Fl_Round_Button(33, 277, 130, 24, "Non-modal");
      rb_3->type(102);
      rb_3->down_box(FL_ROUND_DOWN_BOX);
      rb_3->callback((Fl_Callback*)set_modality, (void*)2);
      } // Fl_Round_Button* rb_3
      o->end();
    } // Fl_Group* o
    sub_win->end();
  } // Fl_Double_Window* sub_win
  { main_win = new Fl_Double_Window(367, 258, "Parent Window");
  { bt_1 = new Fl_Button(25, 25, 95, 40, "Show Child");
  bt_1->callback((Fl_Callback*)cb_show_child);
    } // Fl_Button* bt_1
    { quit_bt = new Fl_Button(290, 215, 64, 35, "Quit");
    quit_bt->callback((Fl_Callback*)cb_quit_bt);
    } // Fl_Button* quit_bt
    { Fl_Light_Button* o = new Fl_Light_Button(100, 180, 115, 40, "Click to test");
    o->selection_color((Fl_Color)5);
    } // Fl_Light_Button* o
    main_win->end();
  } // Fl_Double_Window* main_win
  main_win->show(argc, argv);
  return Fl::run();
}

/* end of file */
